# llm-pdf

![PyPi](https://img.shields.io/pypi/v/llm-pdf-chat?color=green)

---

A CLI utility to index, summarize, and chat with PDF files.

## Installation

```bash
pipx install llm-pdf-chat
```

## Usage

```bash
Usage: llm-pdf [OPTIONS] COMMAND [ARGS]...

Options:
  --version    Show the version and exit.
  --help       Show this message and exit.

Commands:
  arxiv      Download and index a paper from arxiv.
  chat       Chat with your PDFs.
  delete     Reset the collection.
  index      Chat with your PDFs.
  list       Reset the collection.
  summarize  Chat with your PDFs.
```

## Examples

Coming soon!
